Attribute VB_Name = "modGlobals"
Option Explicit

Public Const FIXED_HEIGHT As Long = 315

Public Enum ResStringConstants
    [_min] = 1001
    ResStrCheckPhoneNumberDialogCaption = 1001
    ResStrPhoneDetailsFrameCaption = 1002
    ResStrCountryRegionLabelCaption = 1003
    ResStrCityAreaLabelCaption = 1004
    ResStrLocalNumberLabelCaption = 1005
    ResStrShowAgainCheckBoxCaption = 1006
    ResStrOKButtonCaption = 1007
    ResStrCancelButtonCaption = 1008
    ResStrCountryList = 1009
    ResStrAbout = 1010
    ResStrPhonePropertyPageCaption = 1011
    ResStrAboutBy = 1012
    ResStrAboutAuthor = 1013
    ResStrLine = 1014
    [_max] = 1014
End Enum

Public Enum ResIconConstants
    ResIcoAbout = 1001
End Enum

Public Function LoadResString _
                    ( _
                    p_enmResString As ResStringConstants, _
                    ParamArray p_avntTokens() As Variant _
                    ) As String

    ' We've subclassed the original VB.LoadResString function call to add an extra
    ' parameter. This parameter allows us to specify an indefinite number of values
    ' which we'll use to replace tokens in the string loaded from the resource file.
    ' Tokens shall always be prefixed with the % symbol. We can have as many tokens
    ' in a string as we want to, starting at %1.
    
    Dim v_strExpression As String
    Dim v_lngIdx As Long
    
    On Error GoTo ErrorHandler
    
    If p_enmResString < ResStringConstants.[_min] Or _
        p_enmResString > ResStringConstants.[_max] Then
        
        GoTo ExitHere
        
    End If
    
    v_strExpression = VB.LoadResString(p_enmResString)
    
    If Len(v_strExpression) = 0 Then GoTo ExitHere
    
    For v_lngIdx = LBound(p_avntTokens) To UBound(p_avntTokens)
        
        ' A paramarray always has an LBound of 0. By definition, the fisrt
        ' token index will always be 1, so we have to inrement v_lngIdx by 1
        ' each time in order to replace the correct token
        
        v_strExpression = Replace(v_strExpression, "%" & v_lngIdx + 1, CStr(p_avntTokens(v_lngIdx)))
    
    Next v_lngIdx
    
ExitHere:
    LoadResString = v_strExpression
    Exit Function
ErrorHandler:
    LoadResString = vbNullString
    With VBA.Err
        Debug.Print "Error (" & .Number & ") " & .Description & " in " & .Source
    End With
    Resume ExitHere
End Function

Public Function AddErlToSource _
                        ( _
                        p_strSource As String, _
                        p_lngErl As Long _
                        ) As String
    
    On Error GoTo ErrorHandler
    
    If p_lngErl <> 0 Then
        AddErlToSource = p_strSource & " (" & LoadResString(ResStrLine) & ": " & p_lngErl & ")"
    Else
        AddErlToSource = p_strSource
    End If
    
ExitHere:
    Exit Function
ErrorHandler:
    AddErlToSource = p_strSource
    With VBA.Err
        Debug.Print "Error (" & .Number & ") " & .Description & " in " & .Source
    End With
    Resume ExitHere
End Function

Public Function StripBrackets _
                        ( _
                        ByVal p_strExpression As String _
                        ) As String
    
    On Error GoTo ErrorHandler
    
    p_strExpression = Replace(p_strExpression, "(", vbNullString)
    p_strExpression = Replace(p_strExpression, ")", vbNullString)

    StripBrackets = p_strExpression

ExitHere:
    Exit Function
ErrorHandler:
    Debug.Assert 0  ' Soft stop
    Resume ExitHere
End Function

Public Function StripPlus _
                        ( _
                        ByVal p_strExpression As String _
                        ) As String

    On Error GoTo ErrorHandler
    
    StripPlus = Replace(p_strExpression, "+", vbNullString)

ExitHere:
    Exit Function
ErrorHandler:
    Debug.Assert 0  ' Soft stop
    Resume ExitHere
End Function

